yakumo.cinder.v2

Package yakumo :: Package cinder :: Package v2 |
[hide private]
[frames] | no frames]

# Package v2

source code

Sub client class for Cinder API V2

Submodules | [hide private]
yakumo.cinder.v2.consistency_group: Resource class and its manager for consistency group on Block Storage V2 API yakumo.cinder.v2.consistency_group_snapshot: Resource class and its manager for consistency group snapshot on Block Storage V2 API yakumo.cinder.v2.qos: Resource class and its manager for QoS specifications on Block Storage V2 API yakumo.cinder.v2.quota_set: Resource class and its manager for Quota sets in Block Storage API v2 yakumo.cinder.v2.service: Resource class and its manager for services in Block Storage API v2 yakumo.cinder.v2.snapshot: Resource class and its manager for volume snapshots on Block Storage V2 API yakumo.cinder.v2.volume: Resource class and its manager for volumes on Block Storage V2 API yakumo.cinder.v2.volume_backup: Resource class and its manager for volume backup on Block Storage V2 API yakumo.cinder.v2.volume_transfer: Resource class and its manager for volume transfer on Block Storage V2 API yakumo.cinder.v2.volume_type: Resource class and its manager for volume types on Block Storage V2 API

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo.cinder.v2``'``